==> 2024-10-25_09-48-54.zip: home/pi/ADMIN/CMD/REFRESHER/SCRIPTS/DOWNLOADER.sh <==
#!/bin/bash

ARG="$@"
SCRIPT=$(readlink -f "$0"); PID=$$
DIR=$(cd "$(dirname $SCRIPT)/.." && pwd)
HOMEDIR=$(getent passwd pi | cut -d: -f6)

torrent_file="$HOMEDIR/ADMIN/FILES/TORRENTS/mame078_romset.torrent"
torrent_dir="$HOMEDIR/downloads/MAME2003_Reference_Set_MAME0.78_ROMs_CHDs_Samples/roms"
output_dir="$DIR/roms"

declare -a files=()

# --------------------------------------------------------------------------------------

#[ "$(id -u)" -ne 1000 ] && { echo -e "please run script as user 'pi'"; exit; }

clear; echo "Starting transmission.."
sudo -u pi bash -c 'transmission-daemon'; sleep 1
trap 'sudo rm "$DIR/torrent.dump" 2>/dev/null; exit' INT SIGINT EXIT
#trap 'sudo /etc/init.d/transmission-daemon stop &>/dev/null; sudo pkill -f "transmission-daemon" 2>/dev/null; sudo rm "$DIR/torrent.dump" 2>/dev/null; exit' INT SIGINT EXIT


declare -c id=$(sudo -u pi bash -c 'transmission-remote -l' | grep -A1 '^ID' | tail -n 1 | grep -m1 'MAME' | awk '{print $1}'); echo "ID: $id"
#[[ $id =~ ^[0-9]+$ ]] && { sudo -u pi id=$id bash -c 'transmission-remote -t $id --remove-and-delete'; }
[[ $id =~ ^[0-9]+$ ]] && { sudo -u pi id=$id bash -c 'transmission-remote -t $id -r'; sudo rm $torrent_dir/*.* 2>/dev/null; }

sudo -u pi file=$torrent_file bash -c 'transmission-remote -a $file; while [[ $(transmission-remote -l | grep -c Verifying) -gt 0 ]]; do :; done'
echo "DONE"; sudo -u pi bash -c 'transmission-remote -l'
declare -c id=$(sudo -u pi bash -c 'transmission-remote -l' | grep -A1 '^ID' | tail -n 1 | grep -m1 'MAME' | awk '{print $1}'); echo "ID: $id"

sudo -u pi id=$id bash -c 'transmission-remote -t $id -Gall'
sudo -u pi id=$id bash -c 'transmission-remote -t $id -f' | grep -we 'roms' | sed 's/:.*\/roms\// /' | sudo tee "$DIR/torrent.dump" &>/dev/null

sed 's/\([[:digit:]]\) \+\([[:alnum:]]\)/\1_\2/g' "$DIR/torrent.dump" | grep -v '^.*.chd\|^.*.png' | pr -10T -s' ' | column -t | sed 's/_/ /g'; sleep 1

echo -e "\nWrite id(s) to add.\nENTER to start; ESC to exit.\n"

while true; do read -r -N 1 a; case $a in $'\n') echo "DOWNLOADING"; break ;; $'\E') echo "QUIT"; exit ;; *) read -r b; [[ $a$b =~ ^[0-9]+$ ]] && { files+=($((10#$a$b))); } ;; esac; done

file_list=$(IFS=,; echo "${files[*]}")
log=

if [[ ${#files[@]} -gt 0 ]]; then

  [ -d $output_dir ] && sudo rm $output_dir/* 2>/dev/null

  sudo -u pi id=$id list=$file_list bash -c 'transmission-remote -t $id -g$list'
  sudo -u pi id=$id bash -c 'transmission-remote -t $id --start'

  while true; do
    log=$(sudo -u pi id=$id bash -c 'transmission-remote -t $id -f' | awk '{if ($4 ~ "Yes") print;}');
    for p in $(echo "$log" | awk '{gsub(/%/,"", $2);print $2}'); do [[ $p -lt 100 ]] && { downloading=1; break; }; done; clear
    echo -e "Downloading:\n"; echo "$log" | awk '{n=split($NF,a,"/"); print $1" "a[n]" "$2}' | column -t; sleep 1;
    [[ $(echo "$log" | grep -c '100%') -eq ${#files[@]} ]] && break
  done
fi

while [[ $(sudo find $torrent_dir -type f -iname '*.part' | wc -l) -gt 0 ]]; do sleep 1; done; sleep 2

sleep 1

#sudo find $torrent_dir -maxdepth 1 -type f -iname '*.zip' -exec cp -vf {} $output_dir \;

exit

==> 2024-11-10_21-27-58.zip: home/pi/ADMIN/CMD/REFRESHER/SCRIPTS/DOWNLOADER.sh <==
#!/bin/bash

ARG="$@"
SCRIPT=$(readlink -f "$0"); PID=$$
DIR=$(cd "$(dirname $SCRIPT)/.." && pwd)
HOMEDIR=$(getent passwd pi | cut -d: -f6)

torrent_file="$HOMEDIR/ADMIN/FILES/TORRENTS/mame078_romset.torrent"
torrent_dir="$HOMEDIR/downloads/MAME2003_Reference_Set_MAME0.78_ROMs_CHDs_Samples/roms"
output_dir="$DIR/roms"

declare -a files=()

# --------------------------------------------------------------------------------------

#[ "$(id -u)" -ne 1000 ] && { echo -e "please run script as user 'pi'"; exit; }

clear; echo "Starting transmission.."
sudo -u pi bash -c 'transmission-daemon'; sleep 1
trap 'sudo rm "$DIR/torrent.dump" 2>/dev/null; exit' INT SIGINT EXIT
#trap 'sudo /etc/init.d/transmission-daemon stop &>/dev/null; sudo pkill -f "transmission-daemon" 2>/dev/null; sudo rm "$DIR/torrent.dump" 2>/dev/null; exit' INT SIGINT EXIT


declare -c id=$(sudo -u pi bash -c 'transmission-remote -l' | grep -A1 '^ID' | tail -n 1 | grep -m1 'MAME' | awk '{print $1}'); echo "ID: $id"
#[[ $id =~ ^[0-9]+$ ]] && { sudo -u pi id=$id bash -c 'transmission-remote -t $id --remove-and-delete'; }
[[ $id =~ ^[0-9]+$ ]] && { sudo -u pi id=$id bash -c 'transmission-remote -t $id -r'; sudo rm $torrent_dir/*.* 2>/dev/null; }

sudo -u pi file=$torrent_file bash -c 'transmission-remote -a $file; while [[ $(transmission-remote -l | grep -c Verifying) -gt 0 ]]; do :; done'
echo "DONE"; sudo -u pi bash -c 'transmission-remote -l'
declare -c id=$(sudo -u pi bash -c 'transmission-remote -l' | grep -A1 '^ID' | tail -n 1 | grep -m1 'MAME' | awk '{print $1}'); echo "ID: $id"

sudo -u pi id=$id bash -c 'transmission-remote -t $id -Gall'
sudo -u pi id=$id bash -c 'transmission-remote -t $id -f' | grep -we 'roms' | sed 's/:.*\/roms\// /' | sudo tee "$DIR/torrent.dump" &>/dev/null

#sed 's/\([[:digit:]]\) \+\([[:alnum:]]\)/\1_\2/g' "$DIR/torrent.dump" | grep -v '^.*.chd\|^.*.png' | pr -10T -s' ' | column -t | sed 's/_/ /g'; sleep 1
#echo -e "\nWrite id(s) to add.\nENTER to start; ESC to exit.\n"
#while true; do read -r -N 1 a; case $a in $'\n') echo "DOWNLOADING"; break ;; $'\E') echo "QUIT"; exit ;; *) read -r b; [[ $a$b =~ ^[0-9]+$ ]] && { files+=($((10#$a$b))); } ;; esac; done


sed -i '/^.*.chd/d;/^.*.png/d' "$DIR/torrent.dump"

entries=($(awk '{ print $1"_"$2; }' "$DIR/torrent.dump")); items=()
for item in "${entries[@]}"; do items+=("${item%%_*}" "${item##*_}" OFF); done
indexes=$(whiptail --checklist "SELECT GAME" 0 0 0 "${items[@]}" 2>&1 1>$(tty))
files=($(echo "$indexes" | sed 's/\x22//g'))

file_list=$(IFS=,; echo "${files[*]}")
log=

if [[ ${#files[@]} -gt 0 ]]; then

  [ -d $output_dir ] && sudo rm $output_dir/* 2>/dev/null

  sudo -u pi id=$id list=$file_list bash -c 'transmission-remote -t $id -g$list'
  sudo -u pi id=$id bash -c 'transmission-remote -t $id --start'

  while true; do
    log=$(sudo -u pi id=$id bash -c 'transmission-remote -t $id -f' | awk '{if ($4 ~ "Yes") print;}');
    for p in $(echo "$log" | awk '{gsub(/%/,"", $2);print $2}'); do [[ $p -lt 100 ]] && { downloading=1; break; }; done; clear
    echo -e "Downloading:\n"; echo "$log" | awk '{n=split($NF,a,"/"); print $1" "a[n]" "$2}' | column -t; sleep 1;
    [[ $(echo "$log" | grep -c '100%') -eq ${#files[@]} ]] && break
  done
else
  exit 1
fi

while [[ $(sudo find $torrent_dir -type f -iname '*.part' | wc -l) -gt 0 ]]; do sleep 1; done; sleep 2

sleep 1

#sudo find $torrent_dir -maxdepth 1 -type f -iname '*.zip' -exec cp -vf {} $output_dir \;

exit 0
